import React from 'react'
import styled from 'styled-components'
import { compose, withHandlers } from 'recompose'
import {
  withModal,
  ConfirmationModal,
} from 'pubsweet-component-modal/src/components'

import { Row, RowItem, LabelHeader, LinkText } from '../UIComponents/FormItems'

const EmailNotifications = ({ subscribed = '', subscribe, unsubscribe }) => (
  <Root>
    <Row noMargin>
      <RowItem>
        <LabelHeader>Email Notifications </LabelHeader>
      </RowItem>
    </Row>
    {!subscribed ? (
      <Row noMargin>
        <RowItem>
          <LinkText onClick={subscribe}>Re-subscribe</LinkText>
        </RowItem>
      </Row>
    ) : (
      <Row noMargin>
        <RowItem>
          <LinkText onClick={unsubscribe}>Unsubscribe</LinkText>
        </RowItem>
      </Row>
    )}
  </Root>
)

export default compose(
  withModal(props => ({
    modalComponent: ConfirmationModal,
  })),
  withHandlers({
    subscribe: ({
      userId,
      showModal,
      hideModal,
      changeEmailSubscription,
    }) => () => {
      showModal({
        title: 'Subscribe to emails',
        subtitle: 'Are you sure you want to subscribe to emails?',
        onConfirm: () => {
          changeEmailSubscription(userId, false)
          hideModal()
        },
        onCancel: hideModal,
      })
    },
    unsubscribe: ({
      userId,
      showModal,
      hideModal,
      changeEmailSubscription,
    }) => () => {
      showModal({
        title: 'Unsubscribe from emails',
        subtitle: 'Are you sure you want to unsubscribe from emails?',
        onConfirm: () => {
          changeEmailSubscription(userId, true)
          hideModal()
        },
        onCancel: hideModal,
      })
    },
  }),
)(EmailNotifications)

// #region styles
const Root = styled.div`
  display: flex;
  flex-direction: column;
  max-width: 30em;
`
// #endregion
